<?php
/**
 * $Id:$
 *
 * KnowledgeTree Open Source Edition
 * Document Management Made Simple
 * Copyright (C) 2004 - 2007 The Jam Warehouse Software (Pty) Limited
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You can contact The Jam Warehouse Software (Pty) Limited, Unit 1, Tramber Place,
 * Blake Street, Observatory, 7925 South Africa. or email info@knowledgetree.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * KnowledgeTree" logo and retain the original copyright notice. If the display of the
 * logo is not reasonably feasible for technical reasons, the Appropriate Legal Notices
 * must display the words "Powered by KnowledgeTree" and retain the original
 * copyright notice.
 * Contributor( s): ______________________________________
 *
 */

require_once('ajax.inc.php');

$userID = AjaxSearchHelper::getSessionUser();
$txtQuery = AjaxSearchHelper::checkGET('txtQuery',AjaxSearchHelper::STATUS_MISSING_QUERY ,_kt('Query is empty'));

AjaxSearchHelper::parseQuery($txtQuery, false);

if (array_key_exists('iSavedId',$_GET))
{
	$iSavedId = AjaxSearchHelper::checkGET('iSavedId', AjaxSearchHelper::STATUS_MISSING_SAVED, _kt('Saved search ID is missing'));

	if (!is_numeric($iSavedId))
	{
		AjaxHelper::ajaxResponse(AjaxSearchHelper::STATUS_MISSING_SAVED, _kt('Saved search ID is not numeric') );
	}

	AjaxSearchHelper::updateQuery($iSavedId, $txtQuery, $userID);

}
else
{
	$txtName = AjaxSearchHelper::checkGET('txtName',AjaxSearchHelper::STATUS_MISSING_NAME ,_kt('Query name is empty'));

	AjaxSearchHelper::saveQuery($txtName, $txtQuery, $userID);

}












?>